#!/usr/bin/gawk -f

BEGIN{
  km = 1.e3;  # m
  cm = 1.e-2;  # m
  erg = 1.e-7;  # J
  g = 1.e-3;  # kg
  pi = 3.1415926535;

  D_PB = 100.*km;  # m
#  rho = 3000.;  # kg m^-3
  rho = 2700.;  # kg m^-3

  q_fact = 1.;
  Q0 = 9.e7*erg/g;
  B = 0.5*erg/g/(g/cm**3);
  a = -0.36;
  b = 1.36;

  OFMT=CONVFMT="%16.8f";
  print "#",\
    " 1. Q/Q_star_D", \
    " 2. D_LR [km]", \
    " 3. D_LF' [km] <-- if LR does not exist, D_LF' = D_LR", \
    " 4. D_LF [km]", \
    " 5. Durda.sfd file", \
    " 6. exclamation", \
    " 7. Q [J/kg]", \
    " 8. Q^star_D [J/kg]";
  print "# D_PB = ", D_PB/km, " km";
}
(FNR==1){
  j = split(FILENAME, l, "_");
  v_imp = l[2]*km;
  phi_imp = l[3]+0;
  logmassratio = l[4]+0;

  massratio = 10.**(-logmassratio);
  d_project = D_PB*massratio**(1./3.);
  m_project = 4./3.*pi*(d_project/2.)**3*rho;
  M_PB = 4./3.*pi*(D_PB/2.)**3*rho;
  Q = 1./2.*m_project*v_imp**2/(M_PB+m_project);

  Q_star_D_ = Q_star_D(D_PB/2.);

#  print "# v_imp = ", v_imp/km, " km s^-1";
#  print "# phi_imp = ", phi_imp, " deg";
#  print "# logmassratio = ", logmassratio;
#  print "# d_project = ", d_project/km, " km";
#  print "# Q = ", Q, " J kg^-1";
#  print "# Q_star_D = ", Q_star_D_, " J kg^-1";
#  print "# Q/Q_star_D = ", Q/Q_star_D_;
#  print "";

}
(FNR==1){
  D_LR = $1+0.0;
}
(FNR==2){
  D_LF = $1+0.0;
  if (D_LR/D_LF < 1.2) {
    D_LF_ = D_LR;
    excl = "!";
  } else {
    D_LF_ = D_LF;
    excl = ".";
  }
  print Q/Q_star_D_, D_LR, D_LF_, D_LF, FILENAME, Q, Q_star_D_, excl;
}

func Q_star_D(r) {
  return (1./q_fact*(Q0*(r/cm)**a + B*rho*(r/cm)**b));
}


